{% extends 'bp_util_base.html' %}

{% block content %}
 <div class="divFadeIn">

    <div class="divBarToolsBg">
        <div class="divToolsBgColor">
            <div class="divToolsBodyText">
                <div class="btn-teal"
                    onclick="javascript:location.href='{{url_for('eisenutil_bp.edit_all')}}'">&#9166; return
                </div>
                <hr>
                <form method="POST" enctype="multipart/form-data" id="editFormPage" action="edit">
                    <div class="form-group">
                        <p>Your Radio name is used as the folder name. Spaces will be removed.</p>
                        <label for="title"><b>Name</b>
                        <input type="text" name="title" id="title" placeholder="Post title"
                               class="form-control"
                               value="{{ post['title'] }}"
                               required size="50">
                        </label>
                    </div>
                    <hr>

                    <!-- URL-->
                    <div class="form-group">
                        <label for="content"><b>URL</b>
                            <input type="text" name="content" id="content"
                                   class="form-control"
                                   value="{{ post['content'] }}"
                                   required size="50">
                        </label>
                    </div>
                    <hr>

                    <!-- Image Upload-->
                    <div class="form-group">
                        <label for="inputFile">Image input (jpg, png, bmp, gif, svg)</label>

                        <input class="form-control-file" type="file" name="inputFile" id="inputFile">
                    </div>
                    <hr>

                    <!-- Text description -->
                    <div class="form-group">
                        <label for="text">Write Text
                        <textarea class="form-control" name="text" id="text"
                                  rows="10"
                                  cols="50"
                                  placeholder="Your description">{{ post['pic_comment'] }}</textarea>
                        </label>
                    </div>

                    <div class="form-group">
                        <button type="submit" class="btn btn-primary btn-sm">Submit</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
 </div>

<div id="divConfirmDialog">
    <p id="pConfirmDialogText"></p>
    <div id="btnConfirm"></div>
</div>
{% endblock %}
